@@ -1,6 +1,6 @@
 package Net::StackExchange::Owner;
 BEGIN {
-  $Net::StackExchange::Owner::VERSION = '0.102650';
+  $Net::StackExchange::Owner::VERSION = '0.102740';
 }
 
 # ABSTRACT: Attributes to represent a user
@@ -8,7 +8,12 @@ BEGIN {
 use Moose;
 use Moose::Util::TypeConstraints;
 
-has 'user_id' => (
+has [
+    qw{
+        user_id
+        reputation
+      }
+    ] => (
     is       => 'rw',
     isa      => 'Int',
     required => 1,
@@ -20,19 +25,12 @@ has 'user_type' => (
     required => 1,
 );
 
-has 'display_name' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 1,
-);
-
-has 'reputation' => (
-    is       => 'rw',
-    isa      => 'Int',
-    required => 1,
-);
-
-has 'email_hash' => (
+has [
+    qw{
+        display_name
+        email_hash
+      }
+    ] => (
     is       => 'rw',
     isa      => 'Str',
     required => 1,
@@ -55,7 +53,7 @@ Net::StackExchange::Owner - Attributes to represent a user
 
 =head1 VERSION
 
-version 0.102650
+version 0.102740
 
 =head1 SYNOPSIS
 
